[gnome-shell/gnome-3-0] StTextureCache: plug leak in not-found icon case



commit 1278e31b65e08c31a4d1ac59dea11fe891897857
Author: Colin Walters <walters verbum org>
Date:   Thu May 5 16:28:05 2011 -0400

    StTextureCache: plug leak in not-found icon case
    
    Need to free the key too.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=649508

 src/st/st-texture-cache.c |    3 ++-
 1 files changed, 2 insertions(+), 1 deletions(-)
---
diff --git a/src/st/st-texture-cache.c b/src/st/st-texture-cache.c
index 182851b..fba794a 100644
--- a/src/st/st-texture-cache.c
+++ b/src/st/st-texture-cache.c
@@ -1223,10 +1223,11 @@ load_gicon_with_colors (StTextureCache    *cache,
   else
     {
       /* Blah; we failed to find the icon, but we've added our texture to the outstanding
        * requests.  In that case, just undo what create_texture_lookup_status did.
        */
        g_slist_foreach (request->textures, (GFunc) g_object_unref, NULL);
        g_slist_free (request->textures);
+       g_free (request->key);
        g_free (request);
        g_hash_table_remove (cache->priv->outstanding_requests, key);
        g_object_unref (texture);
@@ -1223,10 +1223,11 @@ load_gicon_with_colors (StTextureCache    *cache,
     {
       /* Blah; we failed to find the icon, but we've added our texture to the outstanding
-       * requests.  In that case, just undo what create_texture_lookup_status did.
+       * requests.  In that case, just undo what create_texture_and_ensure_request() did.
        */
        g_slist_foreach (request->textures, (GFunc) g_object_unref, NULL);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]